@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     04.10.99
-// RCS-ID:      $Id: init.cpp 47412 2007-07-13 02:36:29Z DE $
+// RCS-ID:      $Id: init.cpp 50009 2007-11-16 23:41:38Z VZ $
 // Copyright:   (c) Vadim Zeitlin
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -394,8 +394,12 @@ void wxEntryCleanup()
     {
         wxTheApp->CleanUp();
 
-        delete wxTheApp;
+        // reset the global pointer to it to NULL before destroying it as in
+        // some circumstances this can result in executing the code using
+        // wxTheApp and using half-destroyed object is no good
+        wxAppConsole * const app = wxApp::GetInstance();
         wxApp::SetInstance(NULL);
+        delete app;
     }
 
 
